@@ -16,8 +16,9 @@ Work with embedded documents.
     db.insert(doc)
 """
 
+from yadm.common import EnclosedDocDescriptor
 from yadm.fields.base import Field
-from yadm.serialize import to_mongo
+from yadm.serialize import to_mongo, from_mongo
 
 
 class EmbeddedDocumentField(Field):
@@ -25,16 +26,24 @@ class EmbeddedDocumentField(Field):
 
     :param EmbeddedDocument embedded_document_class: class for embedded document
     """
+
+    embedded_document_class = EnclosedDocDescriptor('embedded')
+
     def __init__(self, embedded_document_class):
         self.embedded_document_class = embedded_document_class
 
     def prepare_value(self, value):
-        if isinstance(value, dict):
+        if value is None:
+            return None
+
+        elif isinstance(value, dict):
             value = self.embedded_document_class(**value)
+
         elif not isinstance(value, self.embedded_document_class):
-            raise TypeError('Only {!r} or dict is alowed, but {!r} given'
+            raise TypeError('Only {!r}, dict or None is alowed, but {!r} given'
                             ''.format(self.embedded_document_class, type(value)))
 
+        # value.__parent__ = document
         value.__name__ = self.name
         return value
 
@@ -42,8 +51,11 @@ class EmbeddedDocumentField(Field):
         return to_mongo(value)
 
     def from_mongo(self, document, value):
-        if not isinstance(value, self.embedded_document_class):
-            value = self.embedded_document_class(**value)
+        if value is None:
+            return None
+
+        elif not isinstance(value, self.embedded_document_class):
+            value = from_mongo(self.embedded_document_class, value, clear_fields_changed=True)
 
         value.__name__ = self.name
         return value
