@@ -27,6 +27,7 @@ TODO: many2many collections
 
 from bson import ObjectId
 
+from yadm.common import EnclosedDocDescriptor
 from yadm.documents import Document
 from yadm.fields.base import Field, FieldDescriptor
 from yadm.serialize import from_mongo
@@ -51,15 +52,18 @@ class ReferenceField(Field):
 
     :param reference_document_class: class for refered documents
     """
+
     descriptor_class = ReferenceFieldDescriptor
+    reference_document_class = EnclosedDocDescriptor('reference')
 
     def __init__(self, reference_document_class):
         self.reference_document_class = reference_document_class
 
     def from_mongo(self, document, value):
-        from yadm.documents import Document  # recursive imports
+        if value is None:
+            return None
 
-        if isinstance(value, (ObjectId, str)):
+        elif isinstance(value, (ObjectId, str)):
             if document.__db__ is not None:
                 qs = document.__db__.get_queryset(self.reference_document_class)
                 doc = qs.with_id(value)
@@ -75,10 +79,12 @@ class ReferenceField(Field):
             return value
 
         else:
-            raise TypeError('value must be ObjectId, Document or dict')
+            raise TypeError('value must be ObjectId, Document, dict, or None'
+                            ' but {!r} given'.format(type(value)))
 
     def to_mongo(self, document, value):
-        from yadm.documents import Document  # recursive imports
+        if value is None:
+            return None
 
         if isinstance(value, ObjectId):
             return value
@@ -90,5 +96,5 @@ class ReferenceField(Field):
             return value.id
 
         else:
-            raise TypeError('value must be ObjectId, Document or dict,'
+            raise TypeError('value must be ObjectId, Document, dict, or None,'
                             ' but {!r}'.format(type(value)))
